Generalized Matthew Corrlelation  Coefficient (MCC)

This package offers tools for calcualting (MCC)  
ttps://towardsdatascience.com/the-best-classification-metric-youve-never-heard-of-the-matthews-correlation-coefficient-3bf50a2f3e9a

The purpose was taking the knwon MCC and extending it to work on multi-class problems